==> lc-driver-3.0.0.tgz: package/index.js <==
const {mouse, keyboard} = require('./src/device');
const {runByEval} = require('./src/util/eval');
const {cancelSignalBlocked} = require('./src/page/prevent');
const {scrollByElement, getElementClientPosition, getElementRect} = require('./src/util/element');
const {$} = require('./src/util');
const accessor = require('./src/page/accessor');
const state = require('./src/state');

function selectElement(selector) {
	return new Promise((resolve, reject) => {
		const element = $(selector)[0];
		if (element) {
			state.emit('element-query-success', element);
			return resolve(element);
		} else {
			const err = new Error('No matched element to selector.');
			state.error('element-query-fail', err);
			return reject(err);
		}
	});
}

function querySelectElementOf(optionElement) {
	let parent = optionElement.parentElement;

	while (parent.tagName !== 'SELECT') {
		parent = parent.parentElement;
	}
	
	return parent;
}

function accessOptionElement(optionElement) {
	if (optionElement.tagName !== 'OPTION') {
		throw new Error('This element is not a <option>.');
	}

	const selectElement = querySelectElementOf(optionElement);
	accessor(selectElement).setValue(optionElement.index);
}

state.mouse = mouse;
state.action = {
	click({selector, offset, button = 'left'}) {
		return this.move({selector, offset})
			.then(target => {
				if (target.tagName === 'OPTION') {
					accessOptionElement(target); 
				}

				return mouse.clickButton(button).then(() => target);
			});
	},
	dblclick({selector, offset, button = 'left'}) {
		return this.click({selector, offset})
			.then(target => mouse.clickButton(button)
				.then(() => target));
	},
	hold({selector, offset, button = 'left'}) {	
		return this.move({selector, offset}).then(target => {
			mouse.holdButton(button);
			return target;
		});
	},
	drop() {
		return Promise.resolve(mouse.release());
	},
	move({selector, offset, autoDrop}) {
		return this.scroll({selector, offset}).then(target => {
			return mouse.moveTo(getElementClientPosition(target)).then(() => {
				state.update('page', clone => {
					clone.currentElement = target;
				});
				if (autoDrop === true) {
					mouse.release();
				}
				return target;
			});
		});
	},
	scroll({selector}) {
		return this.checkState().then(uploading => {
			if (uploading) {
				throw new Error('Input a file to cancel uploading.');
			} 

			return selectElement(selector).then(element => {
				return scrollByElement(element);
			});
		});
	},
	input({selector, value}) {
		return this.move({selector}).then(target => {
			if (target !== state.get('page').focusElement) {
				return mouse.clickButton('left').then(() => target);
			}

			return target;
		}).then(target => {
			return accessor(target).setValue(value);
		});
	},
	keydown({code}) {
		return keyboard.downKey(code);
	},
	keyup({code}) {
		return keyboard.upKey(code);
	},
	keypress({code}) {
		return keyboard.pressKey(code);
	},
	checkState() {
		return Promise.resolve(state.get('prevent-signal').uploading);
	},
};

state.query = {
	cursor({selector}) {
		return selectElement(selector)
		.then(element => getComputedStyle(element).cursor)
		.catch(() => 'default');
	},
	display({selector}) {
		return selectElement(selector)
		.then(element => accessor(element).isDisplay)
		.catch(() => null);
	},
	number({selector}) {
		return Promise.resolve($(selector).length);
	},
	value({selector}) {
		return selectElement(selector)
		.then(element => accessor(element).getValue())
		.catch(() => null);
	},
	attribute({selector, attrName}) {
		return selectElement(selector)
		.then(element => accessor(element).getAttr(attrName))
		.catch(() => null);
	},
	style({selector, cssProperty}) {
		return selectElement(selector)
		.then(element => accessor(element).getStyle(cssProperty))
		.catch(() => '');
	},
	rect({selector}) {
		return selectElement(selector)
		.then(element => getElementRect(element))
		.catch(() => null);
	},
    uploading() {

    },
    uploadInput() {

    }
};

state.runByEval = runByEval;

state.setDocumentGetter = function(getter) {
	if(typeof getter !== 'function') {
		state.error('set-document-getter', new Error('The getter is not a valid function.'));
	}
	state.$documentGetter = getter;
};

state.document = function() {
	const getter = state.$documentGetter;

	if(getter) {
		return getter();
	} else {
		return window.document;
	}
};

state.on('error', err => {
	console.error(`Error: ${err.title}`);
});

state.init = function initState(stateList) {
	for(let s of stateList) {
		state.set(s.groupName, s.state, true);
	}
};

state.prevent = function (value = true) {
	state.update('prevent-signal', clone => {
		clone.prevent = Boolean(value);
	});
	cancelSignalBlocked();
};

module.exports = state.driver = state;

==> lc-driver-3.0.3.tgz: package/index.js <==
const {mouse, keyboard} = require('./src/device');
const {runByEval} = require('./src/util/eval');
const {cancelSignalBlocked} = require('./src/page/prevent');
const {scrollByElement, getElementClientPosition, getElementRect} = require('./src/util/element');
const {$} = require('./src/util');
const accessor = require('./src/page/accessor');
const state = require('./src/state');

function selectElement(selector) {
	return new Promise((resolve, reject) => {
		const element = $(selector)[0];
		if (element) {
			state.emit('element-query-success', getElementRect(element), element);
			return resolve(element);
		} else {
			const err = new Error('No matched element to selector.');
			state.error('element-query-fail', err);
			return reject(err);
		}
	});
}

function querySelectElementOf(optionElement) {
	let parent = optionElement.parentElement;

	while (parent.tagName !== 'SELECT') {
		parent = parent.parentElement;
	}
	
	return parent;
}

function accessOptionElement(optionElement) {
	if (optionElement.tagName !== 'OPTION') {
		throw new Error('This element is not a <option>.');
	}

	const selectElement = querySelectElementOf(optionElement);
	accessor(selectElement).setValue(optionElement.index);
}

state.mouse = mouse;
state.action = {
	click({selector, offset, button = 'left'}) {
		return this.move({selector, offset})
			.then(target => {
				if (target.tagName === 'OPTION') {
					accessOptionElement(target); 
				}

				return mouse.clickButton(button).then(() => target);
			});
	},
	dblclick({selector, offset, button = 'left'}) {
		return this.click({selector, offset})
			.then(target => mouse.clickButton(button)
				.then(() => target));
	},
	hold({selector, offset, button = 'left'}) {	
		return this.move({selector, offset}).then(target => {
			mouse.holdButton(button);
			return target;
		});
	},
	drop() {
		return Promise.resolve(mouse.release());
	},
	move({selector, offset, autoDrop}) {
		return this.scroll({selector, offset}).then(target => {
			return mouse.moveTo(getElementClientPosition(target)).then(() => {
				state.update('page', clone => {
					clone.currentElement = target;
				});
				if (autoDrop === true) {
					mouse.release();
				}
				return target;
			});
		});
	},
	scroll({selector}) {
		return Promise.resolve(state.get('prevent-signal').uploading)
		.then(uploading => {
			if (uploading) {
				throw new Error('Input a file to cancel uploading.');
			} 

			return selectElement(selector).then(element => {
				return scrollByElement(element);
			});
		});
	},
	input({selector, value}) {
		return this.move({selector}).then(target => {
			if (target !== state.get('page').focusElement) {
				return mouse.clickButton('left').then(() => target);
			}

			return target;
		}).then(target => {
			return accessor(target).setValue(value);
		});
	},
	keydown({code}) {
		return keyboard.downKey(code);
	},
	keyup({code}) {
		return keyboard.upKey(code);
	},
	keypress({code}) {
		return keyboard.pressKey(code);
	}
};

state.query = {
	cursor({selector}) {
		return selectElement(selector)
		.then(element => getComputedStyle(element).cursor)
		.catch(() => 'default');
	},
	display({selector}) {
		return selectElement(selector)
		.then(element => accessor(element).isDisplay)
		.catch(() => null);
	},
	number({selector}) {
		return Promise.resolve($(selector).length);
	},
	value({selector}) {
		return selectElement(selector)
		.then(element => accessor(element).getValue())
		.catch(() => null);
	},
	attribute({selector, attrName}) {
		return selectElement(selector)
		.then(element => accessor(element).getAttr(attrName))
		.catch(() => null);
	},
	style({selector, cssProperty}) {
		return selectElement(selector)
		.then(element => accessor(element).getStyle(cssProperty))
		.catch(() => '');
	},
	rect({selector}) {
		return selectElement(selector)
		.then(element => getElementRect(element))
		.catch(() => null);
	},
	uploading() {
		return Promise.resolve(state.get('prevent-signal').uploading);
	},
	uploadInput() {
		return Promise.resolve(state.get('prevent-signal').target);
	}
};

state.runByEval = runByEval;

state.setDocumentGetter = function(getter) {
	if(typeof getter !== 'function') {
		state.error('set-document-getter', new Error('The getter is not a valid function.'));
	}
	state.$documentGetter = getter;
};

state.document = function() {
	const getter = state.$documentGetter;

	if(getter) {
		return getter();
	} else {
		return window.document;
	}
};

state.init = function initState(stateList) {
	for(let s of stateList) {
		state.set(s.groupName, s.state, true);
	}
};

state.prevent = function (value = true) {
	state.update('prevent-signal', clone => {
		clone.prevent = Boolean(value);
	});
	cancelSignalBlocked();
};

module.exports = state.driver = state;
